@@ -209,8 +209,8 @@ GLMM_MCMCifit <- function(do.init, na.complete,
         if (do.init){
           FORM <- formula("y ~ 1")
           if (dist[s] %in% c("gaussian"))               ifit <- lm(FORM, data=dta)
-          else if (dist[s] %in% c("binomial(logit)"))   ifit <- glm(FORM, family=binomial(link=logit), data=dta)
-               else if (dist[s] %in% c("poisson(log)")) ifit <- glm(FORM, family=poisson(link=log), data=dta)
+          else if (dist[s] %in% c("binomial(logit)"))   ifit <- glm(FORM, family=binomial(link = "logit"), data=dta)
+               else if (dist[s] %in% c("poisson(log)")) ifit <- glm(FORM, family=poisson(link = "log"), data=dta)
           sifit <- summary(ifit)
 
           ifixef[[s]] <- 0          
@@ -229,8 +229,8 @@ GLMM_MCMCifit <- function(do.init, na.complete,
         if (do.init){        
           FORM <- formula(paste("y ~", paste(colnames(x[[s]]), collapse=" + ")))
           if (dist[s] %in% c("gaussian"))               ifit <- lm(FORM, data=dta)
-          else if (dist[s] %in% c("binomial(logit)"))   ifit <- glm(FORM, family=binomial(link=logit), data=dta)
-               else if (dist[s] %in% c("poisson(log)")) ifit <- glm(FORM, family=poisson(link=log), data=dta)          
+          else if (dist[s] %in% c("binomial(logit)"))   ifit <- glm(FORM, family=binomial(link = "logit"), data=dta)
+               else if (dist[s] %in% c("poisson(log)")) ifit <- glm(FORM, family=poisson(link = "log"), data=dta)          
           sifit <- summary(ifit)
 
           ifixef[[s]] <- data.frame(Est=coef(ifit)[-1], SE=sifit[["coefficients"]][-1, "Std. Error"])
@@ -272,8 +272,8 @@ GLMM_MCMCifit <- function(do.init, na.complete,
             FORM <- formula(paste("y ~ 1 +", paste(colnames(z[[s]]), collapse=" + "), " + (-1 +", paste(colnames(z[[s]]), collapse=" + "), " | id)"))
             OPT <- options(warn = -1)                      ### added on 20140521 (version 3.6)
             if (dist[s] %in% c("gaussian"))               ifit <- lme4::lmer(FORM, data=dta)
-            else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link=logit), data=dta)
-                 else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link=log), data=dta)
+            else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link = "logit"), data=dta)
+                 else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link = "log"), data=dta)
             options(OPT)                                   ### added on 20140521 (version 3.6)
 
             iintcpt[s, "Est"] <- lme4::fixef(ifit)["(Intercept)"]
@@ -296,8 +296,8 @@ GLMM_MCMCifit <- function(do.init, na.complete,
               FORM <- formula("y ~ 1 + (1 | id)")
               OPT <- options(warn = -1)                      ### added on 20140521 (version 3.6)
               if (dist[s] %in% c("gaussian"))               ifit <- lme4::lmer(FORM, data=dta)
-              else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link=logit), data=dta)
-                   else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link=log), data=dta)
+              else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link = "logit"), data=dta)
+                   else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link = "log"), data=dta)
               options(OPT)                                   ### added on 20140521 (version 3.6)              
 
               iintcpt[s, "Est"] <- 0
@@ -327,8 +327,8 @@ GLMM_MCMCifit <- function(do.init, na.complete,
                 FORM <- formula(paste("y ~ 1 +", paste(colnames(z[[s]]), collapse=" + "), " + (1 +", paste(colnames(z[[s]]), collapse=" + "), " | id)"))
                 OPT <- options(warn = -1)                      ### added on 20140521 (version 3.6)                
                 if (dist[s] %in% c("gaussian"))               ifit <- lme4::lmer(FORM, data=dta)
-                else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link=logit), data=dta)
-                     else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link=log), data=dta)
+                else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link = "logit"), data=dta)
+                     else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link = "log"), data=dta)
                 options(OPT)                                   ### added on 20140521 (version 3.6)
                 
                 iintcpt[s, "Est"] <- 0
@@ -370,8 +370,8 @@ GLMM_MCMCifit <- function(do.init, na.complete,
             FORM <- formula(paste("y ~ 1 +", paste(colnames(x[[s]]), collapse=" + "), " + ", paste(colnames(z[[s]]), collapse=" + "), " + (-1 +", paste(colnames(z[[s]]), collapse=" + "), " | id)"))
             OPT <- options(warn = -1)                      ### added on 20140521 (version 3.6)           
             if (dist[s] %in% c("gaussian"))               ifit <- lme4::lmer(FORM, data=dta)
-            else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link=logit), data=dta)
-                 else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link=log), data=dta)
+            else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link = "logit"), data=dta)
+                 else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link = "log"), data=dta)
             options(OPT)                                   ### added on 20140521 (version 3.6)            
 
             iintcpt[s, "Est"] <- lme4::fixef(ifit)["(Intercept)"]
@@ -402,8 +402,8 @@ GLMM_MCMCifit <- function(do.init, na.complete,
               FORM <- formula(paste("y ~ 1 +", paste(colnames(x[[s]]), collapse=" + "), " + (1 | id)"))
               OPT <- options(warn = -1)                      ### added on 20140521 (version 3.6)
               if (dist[s] %in% c("gaussian"))               ifit <- lme4::lmer(FORM, data=dta)
-              else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link=logit), data=dta)
-                   else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link=log), data=dta)                          
+              else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link = "logit"), data=dta)
+                   else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link = "log"), data=dta)
               options(OPT)                                   ### added on 20140521 (version 3.6)
               
               iintcpt[s, "Est"] <- 0
@@ -436,8 +436,8 @@ GLMM_MCMCifit <- function(do.init, na.complete,
                 FORM <- formula(paste("y ~ 1 +", paste(colnames(x[[s]]), collapse=" + "), " + ", paste(colnames(z[[s]]), collapse=" + "), " + (1 +", paste(colnames(z[[s]]), collapse=" + "), " | id)"))
                 OPT <- options(warn = -1)                      ### added on 20140521 (version 3.6)
                 if (dist[s] %in% c("gaussian"))               ifit <- lme4::lmer(FORM, data=dta)
-                else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link=logit), data=dta)
-                     else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link=log), data=dta)                            
+                else if (dist[s] %in% c("binomial(logit)"))   ifit <- lme4::glmer(FORM, family=binomial(link = "logit"), data=dta)
+                     else if (dist[s] %in% c("poisson(log)")) ifit <- lme4::glmer(FORM, family=poisson(link = "log"), data=dta)                            
                 options(OPT)                                   ### added on 20140521 (version 3.6)
                 
                 iintcpt[s, "Est"] <- 0
