@@ -5,6 +5,7 @@
 //             arnost.komarek[AT]mff.cuni.cz
 //
 //  CREATED:   07/11/2007
+//             19/04/2022 FCONE added where needed
 //
 // ======================================================================
 //
@@ -137,7 +138,7 @@ updateMeansVars_NC(double* mu,
     // AK_Basic::printLT(XiInv4Q, *p);           // DEBUG CODE
 
     /*** Cholesky decomposition of XiInv4Q, store it again in XiInv4Q ***/
-    F77_CALL(dpptrf)("L", p, XiInv4Q, err);                 /** this should never fail... **/
+    F77_CALL(dpptrf)("L", p, XiInv4Q, err FCONE);                 /** this should never fail... **/
     if (*err) error("NMix::updateMeansVars_NC:  Cholesky decomposition of the Wishart inverse scale matrix failed.\n");
 
     // printf("Cholesky decomposition of XiInv4Q[%d]:\n", j);              // DEBUG CODE
@@ -156,7 +157,7 @@ updateMeansVars_NC(double* mu,
       dP++;
       QP++;
     }
-    F77_CALL(dpptrf)("L", p, LiP, err);                 /** this should never fail... **/
+    F77_CALL(dpptrf)("L", p, LiP, err FCONE);                 /** this should never fail... **/
     if (*err) error("NMix::updateMeansVars_NC:  Cholesky decomposition of the sampled component inverse covariance matrix failed.\n");
 
     // printf("Li[%d]:\n", j);                    // DEBUG CODE
@@ -170,7 +171,7 @@ updateMeansVars_NC(double* mu,
       SigmaP++;
       cdP++;
     }
-    F77_CALL(dpptri)("L", p, Sigma_j, err);
+    F77_CALL(dpptri)("L", p, Sigma_j, err FCONE);
     if (*err) error("NMix::updateMeansVars_NC:  Computation of Sigma failed.\n");
 
     // printf("Sigma[%d]:\n", j);                          // DEBUG CODE
@@ -331,7 +332,7 @@ updateMeansVars_IC(double* mu,
     //AK_Basic::printSP(XiInv4Q_OR_Li4mu, *p);              // DEBUG CODE
 
     /*** Cholesky decomposition of XiInv4Q, store it again in XiInv4Q_OR_Li4mu ***/
-    F77_CALL(dpptrf)("L", p, XiInv4Q_OR_Li4mu, err);                 /** this should never fail... **/
+    F77_CALL(dpptrf)("L", p, XiInv4Q_OR_Li4mu, err FCONE);                 /** this should never fail... **/
     if (*err) error("NMix::updateMeansVars_IC:  Cholesky decomposition of the Wishart inverse scale matrix failed.\n");
 
     //Rprintf((char*)("zeta=%g,  mixN=%d,  zeta+mixN=%g\n"), *zeta, *mixNP, n_plus_zeta);                  // DEBUG CODE
@@ -352,7 +353,7 @@ updateMeansVars_IC(double* mu,
       LiP++;
       cdP++;
     }
-    F77_CALL(dpptrf)("L", p, Li_j, err);                 /** this should never fail ... **/
+    F77_CALL(dpptrf)("L", p, Li_j, err FCONE);                 /** this should never fail ... **/
     if (*err) error("NMix::updateMeansVars_IC:  Cholesky decomposition of the sampled component inverse covariance matrix failed.\n");
     //Rprintf((char*)("Cholesky decomposition of Q[%d]: "), j);                 // DEBUG CODE
     //AK_Basic::printArray(Li_j, LTp);                                          // DEBUG CODE
@@ -365,7 +366,7 @@ updateMeansVars_IC(double* mu,
       SigmaP++;
       cdP++;
     }
-    F77_CALL(dpptri)("L", p, Sigma_j, err);
+    F77_CALL(dpptri)("L", p, Sigma_j, err FCONE);
     if (*err) error("NMix::updateMeansVars_IC:  Computation of Sigma failed.\n");
     //Rprintf((char*)("Sigma[%d]: "), j);                                      // DEBUG CODE
     //AK_Basic::printArray(Sigma_j, LTp);                                      // DEBUG CODE
@@ -396,7 +397,7 @@ updateMeansVars_IC(double* mu,
     //AK_Basic::printArray(XiInv4Q_OR_Li4mu, LTp);                                    // DEBUG CODE
 
     /*** Cholesky decomposition of var(mu_j|...)^{-1} ***/
-    F77_CALL(dpptrf)("L", p, XiInv4Q_OR_Li4mu, err);                 /** this should never fail ... **/
+    F77_CALL(dpptrf)("L", p, XiInv4Q_OR_Li4mu, err FCONE);                 /** this should never fail ... **/
     if (*err) error("NMix::updateMeansVars_IC:  Cholesky decomposition of the full conditional inverse covariance matrix of a mixture mean failed.\n");
     //Rprintf((char*)("Cholesky decomposition of the inverse variance of mu[%d]|...: "), j);             // DEBUG CODE
     //AK_Basic::printArray(XiInv4Q_OR_Li4mu, LTp);                                                       // DEBUG CODE
@@ -414,7 +415,7 @@ updateMeansVars_IC(double* mu,
 
     /*** Canonical mean of the full conditional distribution of mu        ***/
     /*** canonical E[mu_j|...] = Q_j*sum_{i: r_i=j}y_i + D_j^{-1}*xi_j    ***/
-    F77_CALL(dspmv)("L", p, &AK_Basic::_ONE_DOUBLE, Q_j, mixSumyP, &AK_Basic::_ONE_INT, &AK_Basic::_ZERO_DOUBLE, canon_m, &AK_Basic::_ONE_INT);
+    F77_CALL(dspmv)("L", p, &AK_Basic::_ONE_DOUBLE, Q_j, mixSumyP, &AK_Basic::_ONE_INT, &AK_Basic::_ZERO_DOUBLE, canon_m, &AK_Basic::_ONE_INT FCONE);
     dP = canon_m;
     for (l = 0; l < *p; l++){
       *dP += *Dinv_xiP;
@@ -533,7 +534,7 @@ updateMeansVars_IC_homoscedastic(double* mu,
   }
 
   /*** Cholesky decomposition of XiInv4Q, store it again in XiInv4Q_OR_Li4mu ***/
-  F77_CALL(dpptrf)("L", p, XiInv4Q_OR_Li4mu, err);                 /** this should never fail... **/
+  F77_CALL(dpptrf)("L", p, XiInv4Q_OR_Li4mu, err FCONE);                 /** this should never fail... **/
   if (*err) error("NMix::updateMeansVars_IC_homoscedastic:  Cholesky decomposition of the Wishart inverse scale matrix failed.\n");
 
   /*** Sample new component inverse variance from the full conditional Wishart ***/
@@ -547,7 +548,7 @@ updateMeansVars_IC_homoscedastic(double* mu,
     LiP++;
     QP++;
   }
-  F77_CALL(dpptrf)("L", p, Li, err);                 /** this should never fail ... **/
+  F77_CALL(dpptrf)("L", p, Li, err FCONE);                 /** this should never fail ... **/
   if (*err) error("NMix::updateMeansVars_IC_homoscedastic:  Cholesky decomposition of the sampled component inverse covariance matrix failed.\n");
 
   /*** Component variance ***/
@@ -558,7 +559,7 @@ updateMeansVars_IC_homoscedastic(double* mu,
     SigmaP++;
     LiP++;
   }
-  F77_CALL(dpptri)("L", p, Sigma, err);
+  F77_CALL(dpptri)("L", p, Sigma, err FCONE);
   if (*err) error("NMix::updateMeansVars_IC_homoscedastic:  Computation of Sigma failed.\n");
     
   /*** log_dets related to the new component inverse variance ***/
@@ -622,7 +623,7 @@ updateMeansVars_IC_homoscedastic(double* mu,
     }
 
     /*** Cholesky decomposition of var(mu_j|...)^{-1} ***/
-    F77_CALL(dpptrf)("L", p, XiInv4Q_OR_Li4mu, err);                 /** this should never fail ... **/
+    F77_CALL(dpptrf)("L", p, XiInv4Q_OR_Li4mu, err FCONE);                 /** this should never fail ... **/
     if (*err) error("NMix::updateMeansVars_IC_homoscedastic:  Cholesky decomposition of the full conditional inverse covariance matrix of a mixture mean failed.\n");
 
     /*** log_dets of the full conditional distribution ***/
@@ -636,7 +637,7 @@ updateMeansVars_IC_homoscedastic(double* mu,
 
     /*** Canonical mean of the full conditional distribution of mu        ***/
     /*** canonical E[mu_j|...] = Q_j*sum_{i: r_i=j}y_i + D_j^{-1}*xi_j    ***/
-    F77_CALL(dspmv)("L", p, &AK_Basic::_ONE_DOUBLE, Q, mixSumyP, &AK_Basic::_ONE_INT, &AK_Basic::_ZERO_DOUBLE, canon_m, &AK_Basic::_ONE_INT);
+    F77_CALL(dspmv)("L", p, &AK_Basic::_ONE_DOUBLE, Q, mixSumyP, &AK_Basic::_ONE_INT, &AK_Basic::_ZERO_DOUBLE, canon_m, &AK_Basic::_ONE_INT FCONE);
     dP = canon_m;
     for (l = 0; l < *p; l++){
       *dP += *Dinv_xiP;
