@@ -6,6 +6,7 @@
 //             arnost.komarek[AT]mff.cuni.cz
 //
 //  CREATED:   19/11/2007
+//             19/04/2022 FCONE added where needed
 //
 // ======================================================================
 //
@@ -45,7 +46,7 @@ BLA(double* beta,
 
     /*** Compute L[i] = Cholesky decomposition of Sigma[-i,-i] ***/
     AK_BLAS::SPjj(L, betaP, sigmaR2P, Sigma, p, &i);
-    F77_CALL(dpptrf)("L", &p_1, L, err);
+    F77_CALL(dpptrf)("L", &p_1, L, err FCONE);
     if (*err) error("Stat::BLA:  Cholesky decomposition of Sigma[-%d,-%d] failed.\n", i, i);
 
     /*** Compute beta[1:(p-1),i] = Sigma[-i,-i]^{-1} %*% Sigma[i,-i]                                           ***/
